@@ -39,7 +39,7 @@
 #define PL_HAVE_GL_PROC_ADDR 1
 #undef PL_HAVE_GLSLANG
 #define PL_HAVE_LCMS 1
-#undef PL_HAVE_LIBDOVI
+#define PL_HAVE_LIBDOVI 1
 #define PL_HAVE_OPENGL 1
 #define PL_HAVE_SHADERC 1
 #define PL_HAVE_VK_PROC_ADDR 1
